Welcome to PyFigureEight's documentation!
=========================================

.. automodule:: figure_eight.figure_eight
    :members: FigureEightClient, FigureEightJob

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
